summaryrefslogtreecommitdiff
path: root/connectivity/source
diff options
context:
space:
mode:
authorTakeshi Abe <tabe@fixedpoint.jp>2010-12-04 13:16:21 +0900
committerCaolán McNamara <caolanm@redhat.com>2010-12-06 09:13:26 +0000
commit50a0d1170ac8cd85373687f00d3b03a9aadefe40 (patch)
treeaef5cba1522c1d9a2f95c9217e709f884618782e /connectivity/source
parentebe931d8572c6698e97907cf042ccd471a15e2b7 (diff)
Replace all occured, occurance etc.
Diffstat (limited to 'connectivity/source')
-rw-r--r--connectivity/source/drivers/ado/APreparedStatement.cxx2
-rw-r--r--connectivity/source/drivers/dbase/DTable.cxx2
-rw-r--r--connectivity/source/drivers/evoab2/NStatement.cxx2
-rw-r--r--connectivity/source/drivers/jdbc/DatabaseMetaData.cxx16
-rw-r--r--connectivity/source/drivers/jdbc/JDriver.cxx2
-rw-r--r--connectivity/source/drivers/jdbc/Object.cxx6
-rw-r--r--connectivity/source/drivers/jdbc/tools.cxx2
-rw-r--r--connectivity/source/drivers/macab/MacabRecords.cxx2
-rw-r--r--connectivity/source/drivers/mozab/MResultSet.cxx2
-rw-r--r--connectivity/source/inc/java/tools.hxx6
-rw-r--r--connectivity/source/parse/sqlnode.cxx2
-rw-r--r--connectivity/source/resource/conn_shared_res.src14
-rw-r--r--connectivity/source/resource/sharedresources.cxx6
13 files changed, 32 insertions, 32 deletions
diff --git a/connectivity/source/drivers/ado/APreparedStatement.cxx b/connectivity/source/drivers/ado/APreparedStatement.cxx
index 3261f6ed08..5b7056c584 100644
--- a/connectivity/source/drivers/ado/APreparedStatement.cxx
+++ b/connectivity/source/drivers/ado/APreparedStatement.cxx
@@ -76,7 +76,7 @@ OPreparedStatement::OPreparedStatement( OConnection* _pConnection,const OTypeInf
OSQLParseNode* pNode = aParser.parseTree(sErrorMessage,sql);
if(pNode)
{ // special handling for parameters
- /* we recusive replace all occurences of ? in the statement and replace them with name like "æ¬å" */
+ /* we recusive replace all occurrences of ? in the statement and replace them with name like "æ¬å" */
sal_Int32 nParameterCount = 0;
::rtl::OUString sDefaultName( RTL_CONSTASCII_USTRINGPARAM( "parame" ));
replaceParameterNodeName(pNode,sDefaultName,nParameterCount);
diff --git a/connectivity/source/drivers/dbase/DTable.cxx b/connectivity/source/drivers/dbase/DTable.cxx
index 88d5b9f0b8..fd941e08a4 100644
--- a/connectivity/source/drivers/dbase/DTable.cxx
+++ b/connectivity/source/drivers/dbase/DTable.cxx
@@ -2281,7 +2281,7 @@ void ODbaseTable::alterColumn(sal_Int32 index,
}
catch(const Exception&)
{
- OSL_ENSURE(0,"ODbaseTable::alterColumn: Exception occured!");
+ OSL_ENSURE(0,"ODbaseTable::alterColumn: Exception occurred!");
throw;
}
}
diff --git a/connectivity/source/drivers/evoab2/NStatement.cxx b/connectivity/source/drivers/evoab2/NStatement.cxx
index 64b65a590d..d7467f50ea 100644
--- a/connectivity/source/drivers/evoab2/NStatement.cxx
+++ b/connectivity/source/drivers/evoab2/NStatement.cxx
@@ -428,7 +428,7 @@ EBookQuery *OCommonStatement::whereAnalysis( const OSQLParseNode* parseTree )
m_pConnection->throwGenericSQLException(STR_QUERY_NOT_LIKE_TOO_COMPLEX,*this);
}
else if( (aMatchString.indexOf ( WILDCARD ) == aMatchString.lastIndexOf ( WILDCARD ) ) )
- { // One occurance of '%' matches...
+ { // One occurrence of '%' matches...
if ( aMatchString.indexOf ( WILDCARD ) == 0 )
pResult = createTest( aColumnName, E_BOOK_QUERY_ENDS_WITH, aMatchString.copy( 1 ) );
else if ( aMatchString.indexOf ( WILDCARD ) == aMatchString.getLength() - 1 )
diff --git a/connectivity/source/drivers/jdbc/DatabaseMetaData.cxx b/connectivity/source/drivers/jdbc/DatabaseMetaData.cxx
index 27d7833272..c426e065d0 100644
--- a/connectivity/source/drivers/jdbc/DatabaseMetaData.cxx
+++ b/connectivity/source/drivers/jdbc/DatabaseMetaData.cxx
@@ -133,7 +133,7 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTables(
// Java-Call absetzen
static jmethodID mID(NULL);
obtainMethodId(t.pEnv, cMethodName,cSignature, mID);
- OSL_VERIFY_RES( !isExceptionOccured(t.pEnv,sal_True),"Exception occured!");
+ OSL_VERIFY_RES( !isExceptionOccurred(t.pEnv,sal_True),"Exception occurred!");
jvalue args[4];
args[3].l = 0;
@@ -141,7 +141,7 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTables(
if ( typeFilterCount )
{
jobjectArray pObjArray = static_cast< jobjectArray >( t.pEnv->NewObjectArray( (jsize)typeFilterCount, java_lang_String::st_getMyClass(), 0 ) );
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
const ::rtl::OUString* typeFilter = _types.getConstArray();
bool bIncludeAllTypes = false;
for ( sal_Int32 i=0; i<typeFilterCount; ++i, ++typeFilter )
@@ -153,7 +153,7 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTables(
}
jstring aT = convertwchar_tToJavaString( t.pEnv, *typeFilter );
t.pEnv->SetObjectArrayElement( pObjArray, (jsize)i, aT );
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
}
if ( bIncludeAllTypes )
@@ -161,7 +161,7 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTables(
// the SDBC API allows to pass "%" as table type filter, but in JDBC, "all table types"
// is represented by the table type being <null/>
t.pEnv->DeleteLocalRef( pObjArray );
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
}
else
{
@@ -189,23 +189,23 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTables(
if ( aCatalogFilter.hasValue() )
{
t.pEnv->DeleteLocalRef((jstring)args[0].l);
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
}
if(args[1].l)
{
t.pEnv->DeleteLocalRef((jstring)args[1].l);
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
}
if(tableNamePattern.getLength())
{
t.pEnv->DeleteLocalRef((jstring)args[2].l);
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
}
//for(INT16 i=0;i<len;i++)
if ( args[3].l )
{
t.pEnv->DeleteLocalRef( (jobjectArray)args[3].l );
- OSL_VERIFY_RES( !isExceptionOccured( t.pEnv, sal_True ), "Exception occured!" );
+ OSL_VERIFY_RES( !isExceptionOccurred( t.pEnv, sal_True ), "Exception occurred!" );
}
if ( jThrow )
diff --git a/connectivity/source/drivers/jdbc/JDriver.cxx b/connectivity/source/drivers/jdbc/JDriver.cxx
index ad9f8d947f..8decaa3751 100644
--- a/connectivity/source/drivers/jdbc/JDriver.cxx
+++ b/connectivity/source/drivers/jdbc/JDriver.cxx
@@ -116,7 +116,7 @@ Reference< XConnection > SAL_CALL java_sql_Driver::connect( const ::rtl::OUStrin
java_sql_Connection* pConnection = new java_sql_Connection( *this );
xOut = pConnection;
if ( !pConnection->construct(url,info) )
- xOut.clear(); // an error occured and the java driver didn't throw an exception
+ xOut.clear(); // an error occurred and the java driver didn't throw an exception
else
m_aLogger.log( LogLevel::INFO, STR_LOG_DRIVER_SUCCESS );
}
diff --git a/connectivity/source/drivers/jdbc/Object.cxx b/connectivity/source/drivers/jdbc/Object.cxx
index 3a7184393f..811c2e5de9 100644
--- a/connectivity/source/drivers/jdbc/Object.cxx
+++ b/connectivity/source/drivers/jdbc/Object.cxx
@@ -281,7 +281,7 @@ sal_Int32 java_lang_Object::callIntMethod( const char* _pMethodName, jmethodID&
// call method
jint out( t.pEnv->CallIntMethod( object, _inout_MethodID ) );
if ( _bIgnoreException )
- isExceptionOccured(t.pEnv,sal_True);
+ isExceptionOccurred(t.pEnv,sal_True);
else
ThrowSQLException( t.pEnv, NULL );
@@ -320,7 +320,7 @@ void java_lang_Object::callVoidMethodWithIntArg( const char* _pMethodName, jmeth
// call method
t.pEnv->CallVoidMethod( object, _inout_MethodID,_nArgument );
if ( _bIgnoreException )
- isExceptionOccured(t.pEnv,sal_True);
+ isExceptionOccurred(t.pEnv,sal_True);
else
ThrowSQLException( t.pEnv, NULL );
}
@@ -333,7 +333,7 @@ void java_lang_Object::callVoidMethodWithBoolArg( const char* _pMethodName, jmet
// call method
t.pEnv->CallVoidMethod( object, _inout_MethodID,_nArgument );
if ( _bIgnoreException )
- isExceptionOccured(t.pEnv,sal_True);
+ isExceptionOccurred(t.pEnv,sal_True);
else
ThrowSQLException( t.pEnv, NULL );
}
diff --git a/connectivity/source/drivers/jdbc/tools.cxx b/connectivity/source/drivers/jdbc/tools.cxx
index 2485943db4..a8b22c0f19 100644
--- a/connectivity/source/drivers/jdbc/tools.cxx
+++ b/connectivity/source/drivers/jdbc/tools.cxx
@@ -191,7 +191,7 @@ jobject connectivity::convertTypeMapToJavaMap(JNIEnv* /*pEnv*/,const Reference<
return 0;
}
// -----------------------------------------------------------------------------
-sal_Bool connectivity::isExceptionOccured(JNIEnv *pEnv,sal_Bool _bClear)
+sal_Bool connectivity::isExceptionOccurred(JNIEnv *pEnv,sal_Bool _bClear)
{
if ( !pEnv )
return sal_False;
diff --git a/connectivity/source/drivers/macab/MacabRecords.cxx b/connectivity/source/drivers/macab/MacabRecords.cxx
index 3b38bc8929..9e005d38e2 100644
--- a/connectivity/source/drivers/macab/MacabRecords.cxx
+++ b/connectivity/source/drivers/macab/MacabRecords.cxx
@@ -939,7 +939,7 @@ void MacabRecords::insertPropertyIntoMacabRecord(const ABPropertyType _propertyT
* scalar type, an error, or an unknown type are found.
* Because of that, the following checks only occur for this type.
* We store whether we have successfully placed this property
- * into the MacabRecord (or whether an unrecoverable error occured).
+ * into the MacabRecord (or whether an unrecoverable error occurred).
* Then, we try over and over again to place the property into the
* record. There are three possible results:
* 1) Success!
diff --git a/connectivity/source/drivers/mozab/MResultSet.cxx b/connectivity/source/drivers/mozab/MResultSet.cxx
index 8ca4e57b81..685c1fe65a 100644
--- a/connectivity/source/drivers/mozab/MResultSet.cxx
+++ b/connectivity/source/drivers/mozab/MResultSet.cxx
@@ -981,7 +981,7 @@ void OResultSet::analyseWhereClause( const OSQLParseNode* parseT
&& matchString.indexOf( MATCHCHAR ) == -1
)
{
- // One occurance of '%' - no '_' matches...
+ // One occurrence of '%' - no '_' matches...
if ( matchString.indexOf ( WILDCARD ) == 0 )
{
op = MQueryOp::EndsWith;
diff --git a/connectivity/source/parse/sqlnode.cxx b/connectivity/source/parse/sqlnode.cxx
index 46993dbc6d..72c8291b61 100644
--- a/connectivity/source/parse/sqlnode.cxx
+++ b/connectivity/source/parse/sqlnode.cxx
@@ -702,7 +702,7 @@ void OSQLParseNode::impl_parseLikeNodeToString_throw( ::rtl::OUStringBuffer& rSt
}
catch ( Exception& )
{
- OSL_ENSURE( false, "OSQLParseNode::impl_parseLikeNodeToString_throw Exception occured!" );
+ OSL_ENSURE( false, "OSQLParseNode::impl_parseLikeNodeToString_throw Exception occurred!" );
}
if ( !m_aChildren[0]->isLeaf() )
{
diff --git a/connectivity/source/resource/conn_shared_res.src b/connectivity/source/resource/conn_shared_res.src
index faccf586a0..9772787cb6 100644
--- a/connectivity/source/resource/conn_shared_res.src
+++ b/connectivity/source/resource/conn_shared_res.src
@@ -131,7 +131,7 @@ String STR_STMT_TYPE_NOT_SUPPORTED
String STR_UNSPECIFIED_ERROR
{
- Text [ en-US ] = "An unknown error occured.";
+ Text [ en-US ] = "An unknown error occurred.";
};
String STR_COULD_NOT_CREATE_ADDRESSBOOK
@@ -146,12 +146,12 @@ String STR_COULD_NOT_LOAD_LIB
String STR_ERROR_REFRESH_ROW
{
- Text [ en-US ] = "An error occured while refreshing the current row.";
+ Text [ en-US ] = "An error occurred while refreshing the current row.";
};
String STR_ERROR_GET_ROW
{
- Text [ en-US ] = "An error occured while getting the current row.";
+ Text [ en-US ] = "An error occurred while getting the current row.";
};
String STR_CAN_NOT_CANCEL_ROW_UPDATE
@@ -171,7 +171,7 @@ String STR_QUERY_INVALID_IS_NULL_COLUMN
String STR_ILLEGAL_MOVEMENT
{
- Text [ en-US ] = "Illegal cursor movement occured.";
+ Text [ en-US ] = "Illegal cursor movement occurred.";
};
String STR_COMMIT_ROW
@@ -383,7 +383,7 @@ String STR_NO_CONNECTION
// dbase
String STR_COULD_NOT_DELETE_INDEX
{
- Text [ en-US ] = "The index could not be deleted. An unknown error while accessing the file system occured.";
+ Text [ en-US ] = "The index could not be deleted. An unknown error while accessing the file system occurred.";
};
String STR_ONL_ONE_COLUMN_PER_INDEX
{
@@ -628,11 +628,11 @@ String STR_INVALID_FILE_URL
};
String STR_NO_TABLE_CONTAINER
{
- Text [ en-US ] = "An error occured while obtaining the connection's table container.";
+ Text [ en-US ] = "An error occurred while obtaining the connection's table container.";
};
String STR_NO_TABLE_EDITOR_DIALOG
{
- Text [ en-US ] = "An error occured while creating the table editor dialog.";
+ Text [ en-US ] = "An error occurred while creating the table editor dialog.";
};
String STR_NO_TABLENAME
{
diff --git a/connectivity/source/resource/sharedresources.cxx b/connectivity/source/resource/sharedresources.cxx
index a08e9bede4..4910b8c78e 100644
--- a/connectivity/source/resource/sharedresources.cxx
+++ b/connectivity/source/resource/sharedresources.cxx
@@ -157,17 +157,17 @@ namespace connectivity
size_t lcl_substitute( ::rtl::OUString& _inout_rString,
const sal_Char* _pAsciiPattern, const ::rtl::OUString& _rReplace )
{
- size_t nOccurences = 0;
+ size_t nOccurrences = 0;
::rtl::OUString sPattern( ::rtl::OUString::createFromAscii( _pAsciiPattern ) );
sal_Int32 nIndex = 0;
while ( ( nIndex = _inout_rString.indexOf( sPattern ) ) > -1 )
{
- ++nOccurences;
+ ++nOccurrences;
_inout_rString = _inout_rString.replaceAt( nIndex, sPattern.getLength(), _rReplace );
}
- return nOccurences;
+ return nOccurrences;
}
}
diff --git a/connectivity/source/inc/java/tools.hxx b/connectivity/source/inc/java/tools.hxx
index 7924edba02..eec4b99c0f 100644
--- a/connectivity/source/inc/java/tools.hxx
+++ b/connectivity/source/inc/java/tools.hxx
@@ -73,15 +73,15 @@ namespace connectivity
::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > Map2XNameAccess(JNIEnv *pEnv,jobject _pMap);
jobject convertTypeMapToJavaMap(JNIEnv *pEnv,const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & _rMap);
/** return if a exception occured
@param pEnv
The native java env
@param _bClear
<TRUE/> if the execption should be cleared
@return
- <TRUE/> if an exception is occured
+ <TRUE/> if an exception is occurred
*/
- sal_Bool isExceptionOccured(JNIEnv *pEnv,sal_Bool _bClear);
+ sal_Bool isExceptionOccurred(JNIEnv *pEnv,sal_Bool _bClear);
jobject createByteInputStream(const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& x,sal_Int32 length);
jobject createCharArrayReader(const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& x,sal_Int32 length);
@@ -73,15 +73,15 @@ namespace connectivity
::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > Map2XNameAccess(JNIEnv *pEnv,jobject _pMap);
jobject convertTypeMapToJavaMap(JNIEnv *pEnv,const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & _rMap);
- /** return if a exception occured
+ /** return if a exception occurred
The native java env